@@ -172,9 +172,9 @@ const SpecialOption specialOptions[] = {
     {"fullscreen_visual_bell", "fade", TRUE,
      METACITY "/general/visual_bell_type", OptionSpecial},
 
-    {"next_key", "switcher", FALSE,
+    {"next_key", "staticswitcher", FALSE,
      METACITY "/global_keybindings/switch_windows", OptionKey},
-    {"prev_key", "switcher", FALSE,
+    {"prev_key", "staticswitcher", FALSE,
      METACITY "/global_keybindings/switch_windows_backward", OptionKey},
 
     {"toggle_sticky_key", "extrawm", FALSE,
@@ -351,11 +351,11 @@ const SpecialOption specialOptions[] = {
     {"rotate_right_window_key", "rotate", FALSE,
      METACITY "/window_keybindings/move_to_workspace_right", OptionKey},
 
-    {"command_screenshot", "core", FALSE,
+    {"command_screenshot", "gnomecompat", FALSE,
      METACITY "/keybinding_commands/command_screenshot", OptionString},
-    {"command_window_screenshot", "core", FALSE,
+    {"command_window_screenshot", "gnomecompat", FALSE,
      METACITY "/keybinding_commands/command_window_screenshot", OptionString},
-    {"command_terminal", "core", FALSE,
+    {"command_terminal", "gnomecompat", FALSE,
      "/desktop/gnome/applications/terminal/exec", OptionString},
 
     {"current_viewport", "thumbnail", TRUE,
@@ -406,7 +406,7 @@ isIntegratedOption (CCSSetting *setting,
 
     for (i = 0; i < N_SOPTIONS; i++)
     {
-	SpecialOption *opt = &specialOptions[i];
+	const SpecialOption *opt = &specialOptions[i];
 
 	if (strcmp (setting->name, opt->settingName) != 0)
 	    continue;
@@ -1834,17 +1834,20 @@ checkProfile (CCSContext *context)
     else
 	currentProfile = strdup (profile);
 
-    if (strcmp (lastProfile, currentProfile) != 0)
+    if (!lastProfile || strcmp (lastProfile, currentProfile) != 0)
     {
 	char *pathName;
 
-	/* copy /apps/compiz tree to profile path */
-	asprintf (&pathName, "%s/%s", PROFILEPATH, lastProfile);
-	if (pathName)
+	if (lastProfile)
 	{
-	    copyGconfTree (context, COMPIZ, pathName,
-	    		   TRUE, "/schemas" COMPIZ);
-	    free (pathName);
+	    /* copy /apps/compiz tree to profile path */
+	    asprintf (&pathName, "%s/%s", PROFILEPATH, lastProfile);
+	    if (pathName)
+	    {
+		copyGconfTree (context, COMPIZ, pathName,
+			       TRUE, "/schemas" COMPIZ);
+		free (pathName);
+	    }
 	}
 
 	/* reset /apps/compiz tree */
